﻿using Caliburn.Micro;
using QuizApplication.Helpers;
using QuizApplication.Models;
using System;
using System.Collections.Generic;
using System.Windows.Controls;
using System.Linq;
using QuizApplication.DataHandler;
using System.Windows;

namespace QuizApplication.ViewModels
{
    class QuizViewModel : Screen
    {
        private string _currentQuestion { get; set; }
        public string CurrentQuestion { get => _currentQuestion; set { _currentQuestion = value; NotifyOfPropertyChange(); } }
        private string _nextBtnText { get; set; }
        public string NextBtnText { get => _nextBtnText; set { _nextBtnText = value; NotifyOfPropertyChange(); } }
        private int? _selectedIndex { get; set; }
        public int? SelectedIndex { get => _selectedIndex; set { _selectedIndex = value; NotifyOfPropertyChange(); } }
        private List<string> _answers { get; set; }
        public List<string> Answers { get => _answers; set { _answers = value; NotifyOfPropertyChange(); } }
        private string _selectedAnswers { get; set; }
        public string SelectedAnswers
        {
            get => _selectedAnswers; set
            {
                _selectedAnswers = value;
                if (!string.IsNullOrEmpty(_selectedAnswers))
                {
                    var answer = _selectedAnswers.Split(".")[0];
                    var correctAnswer = QuestionsList[currentIndex].correctAns;
                    QuestionsList[currentIndex].IsMatch = (answer == correctAnswer) ? true : false;
                    QuestionsList[currentIndex].SelectedIndex = SelectedIndex;
                }
                NotifyOfPropertyChange();
            }
        }

        private List<DbQuestionsModel> QuestionsList;
        private int currentIndex = 0;
        private static Random rng = new Random();

        public QuizViewModel()
        {
            SqlDataHandler sqlDataHandler = new SqlDataHandler();
            NextBtnText = "Next";
            var tempVal = sqlDataHandler.GetQuestions();
            QuestionsList = tempVal.OrderBy(a => rng.Next()).ToList<DbQuestionsModel>();
            if (QuestionsList.Count > 10)
                QuestionsList.RemoveRange(10, QuestionsList.Count - 10);
            setcurrentQuestion();
        }

        private void setcurrentQuestion()
        {
            if (QuestionsList.Count > 0)
            {
                CurrentQuestion = QuestionsList[currentIndex].question;
                Answers = new List<string>();
                Answers.Add(QuestionsList[currentIndex].answer1);
                Answers.Add(QuestionsList[currentIndex].answer2);
                Answers.Add(QuestionsList[currentIndex].answer3);
                Answers.Add(QuestionsList[currentIndex].answer4);
            }
            else
                MessageBox.Show("No Questions");
        }

        private void move()
        {
            NextBtnText = (currentIndex == 9) ? "Finish the exam" : "Next";

            setcurrentQuestion();
            if (QuestionsList[currentIndex].SelectedIndex.HasValue)
                SelectedIndex = QuestionsList[currentIndex].SelectedIndex.Value;
            else
                SelectedIndex = null;
        }

        public void RunOperation(object obj)
        {
            if (QuestionsList.Count > 0)
            {
                var selectedButton = obj as RadioButton;
                currentIndex = Int32.Parse(selectedButton.Tag.ToString());
                move();
            }
            else
                MessageBox.Show("No Questions");
        }

        public void PreviousCommand(object obj)
        {
            if (QuestionsList.Count > 0)
            {
                if (currentIndex != 0)
                {
                    --currentIndex;
                    move();
                    var collection = obj as UIElementCollection;
                    ((RadioButton)collection[currentIndex]).IsChecked = true;
                }
            }
            else
                MessageBox.Show("No Questions");
        }//

        public void NextCommand(object obj)
        {
            if (QuestionsList.Count > 0)
            {
                if (currentIndex != QuestionsList.Count - 1)
                {
                    ++currentIndex;
                    move();
                    var collection = obj as UIElementCollection;
                    ((RadioButton)collection[currentIndex]).IsChecked = true;
                }
                else if (currentIndex == QuestionsList.Count - 1)
                {
                    var noOfCorrectAnswers = QuestionsList.Where(obj => obj.IsMatch == true).Count<DbQuestionsModel>();
                    var outputStr = $"Number of correct answers {noOfCorrectAnswers} out of {QuestionsList.Count}";
                    var conductor = this.Parent as IConductor;
                    conductor.ActivateItemAsync(new ResultViewModel(outputStr));
                }
            }
            else
                MessageBox.Show("No Questions");
        }

    }//
}
